pub struct QuicEndpoint {
inner: Endpoint,
local_endpoint: Endpoint,
}Expand description
A QUIC endpoint that can listen for and initiate connections.
Fields
inner: Endpointlocal_endpoint: EndpointImplementations
Sourceimpl QuicEndpoint
impl QuicEndpoint
Sourcepub async fn listen(
endpoint: &Endpoint,
config: ServerQuicConfig,
) -> Result<Self>
pub async fn listen( endpoint: &Endpoint, config: ServerQuicConfig, ) -> Result<Self>
Bind to a local address and start listening with the given server config.
Sourcepub async fn dial(
endpoint: &Endpoint,
config: ClientQuicConfig,
) -> Result<QuicConn>
pub async fn dial( endpoint: &Endpoint, config: ClientQuicConfig, ) -> Result<QuicConn>
Connect to a remote QUIC endpoint.
Sourcepub fn local_endpoint(&self) -> Result<Endpoint>
pub fn local_endpoint(&self) -> Result<Endpoint>
Returns the local endpoint.